@@ -52,7 +52,7 @@ typedef struct _GisPrivacyPagePrivate GisPrivacyPagePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GisPrivacyPage, gis_privacy_page, GIS_TYPE_PAGE);
 
-static void
+static gboolean
 update_os_data (GisPrivacyPage *page)
 {
   GisPrivacyPagePrivate *priv = gis_privacy_page_get_instance_private (page);
@@ -61,28 +61,27 @@ update_os_data (GisPrivacyPage *page)
   g_autofree char *subtitle = NULL;
 
   if (!name)
-    name = g_strdup ("GNOME");
+    return FALSE;
 
   if (privacy_policy)
     {
       /* Translators: the first parameter here is the name of a distribution,
-       * like "Fedora" or "Ubuntu". It falls back to "GNOME" if we can't
-       * detect any distribution.
+       * like "Fedora" or "Ubuntu".
        */
-      subtitle = g_strdup_printf (_("Sends technical reports that have personal information automatically "
-                                    "removed. Data is collected by %1$s (<a href='%2$s'>privacy policy</a>)."),
-                                  name, privacy_policy);
+      subtitle = g_strdup_printf (_("Sends technical reports that do not contain personal information. "
+                                    "Data is collected by %1$s (<a href='%2$s'>privacy policy</a>)."),
+                                    name, privacy_policy);
     }
   else
     {
       /* Translators: the parameter here is the name of a distribution,
-       * like "Fedora" or "Ubuntu". It falls back to "GNOME" if we can't
-       * detect any distribution.
+       * like "Fedora" or "Ubuntu".
        */
-      subtitle = g_strdup_printf (_("Sends technical reports that have personal information automatically "
-                                    "removed. Data is collected by %s."), name);
+      subtitle = g_strdup_printf (_("Sends technical reports that do not contain personal information. "
+                                    "Data is collected by %s."), name);
     }
   gtk_label_set_markup (GTK_LABEL (priv->reporting_label), subtitle);
+  return TRUE;
 }
 
 static void
@@ -124,15 +123,16 @@ gis_privacy_page_constructed (GObject *object)
   gtk_switch_set_active (GTK_SWITCH (priv->location_switch), TRUE);
   gtk_switch_set_active (GTK_SWITCH (priv->reporting_switch), TRUE);
 
-  update_os_data (page);
-
-  priv->abrt_watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
-                                          "org.freedesktop.problems.daemon",
-                                          G_BUS_NAME_WATCHER_FLAGS_NONE,
-                                          abrt_appeared_cb,
-                                          abrt_vanished_cb,
-                                          page,
-                                          NULL);
+  if (update_os_data (page))
+    {
+      priv->abrt_watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
+                                              "org.freedesktop.problems.daemon",
+                                              G_BUS_NAME_WATCHER_FLAGS_NONE,
+                                              abrt_appeared_cb,
+                                              abrt_vanished_cb,
+                                              page,
+                                              NULL);
+    }
 }
 
 static void
@@ -157,10 +157,10 @@ gis_privacy_page_apply (GisPage *gis_page,
   GisPrivacyPagePrivate *priv = gis_privacy_page_get_instance_private (page);
   gboolean active;
 
-  active = gtk_switch_get_active (GTK_SWITCH (priv->location_switch));
+  active = gtk_widget_is_visible (priv->location_switch) && gtk_switch_get_active (GTK_SWITCH (priv->location_switch));
   g_settings_set_boolean (priv->location_settings, "enabled", active);
 
-  active = gtk_switch_get_active (GTK_SWITCH (priv->reporting_switch));
+  active = gtk_widget_is_visible (priv->reporting_switch) && gtk_switch_get_active (GTK_SWITCH (priv->reporting_switch));
   g_settings_set_boolean (priv->privacy_settings, "report-technical-problems", active);
 
   return FALSE;
